pub(crate) enum Message {
Hello(ChannelAddr),
Echo(Part),
}Variants
Hello(ChannelAddr)
Initial handshake carrying the client’s reply address.
Echo(Part)
Payload echoed back and forth.
Implementations
Sourceimpl Message
impl Message
Sourcepub fn as_hello_mut(&mut self) -> Option<&mut ChannelAddr>
pub fn as_hello_mut(&mut self) -> Option<&mut ChannelAddr>
Optionally returns mutable references to the inner fields if this is a Message::Hello, otherwise None
Sourcepub fn as_hello(&self) -> Option<&ChannelAddr>
pub fn as_hello(&self) -> Option<&ChannelAddr>
Optionally returns references to the inner fields if this is a Message::Hello, otherwise None
Sourcepub fn into_hello(self) -> Result<ChannelAddr, Self>
pub fn into_hello(self) -> Result<ChannelAddr, Self>
Returns the inner fields if this is a Message::Hello, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_echo_mut(&mut self) -> Option<&mut Part>
pub fn as_echo_mut(&mut self) -> Option<&mut Part>
Optionally returns mutable references to the inner fields if this is a Message::Echo, otherwise None